package com.nisum.offertransactionservice.service;

import com.nisum.offertransactionservice.client.StoreProducerFeignClient;
import com.nisum.offertransactionservice.genericexception.CustomCreatedCustomException;
import com.nisum.offertransactionservice.genericexception.GlobalApiGenericException;
import feign.FeignException;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.PropertySource;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import reactor.core.publisher.Mono;


import java.util.Objects;


@Service
@Slf4j
public class EndOfTransactionService {

    @Autowired
    private StoreProducerFeignClient storeProducerFeignClient;

    public String endOfTransaction(String uuid) {
        if (Objects.isNull(uuid) || uuid.isEmpty()) {
            log.error("Offer transaction uuid is empty or null");
            throw new GlobalApiGenericException("Unable to get the Offer transaction uuid ", new Exception("exception e"), "400", false);
        }
        log.info("Store Consumer Feignclient call Start");
        try{
            ResponseEntity<String> endOfTransactionRes = storeProducerFeignClient.callStoreProducer(uuid);
            log.debug("Store consumer Feignclient call End");
            return endOfTransactionRes.getBody();
        }catch (FeignException e){
            throw new CustomCreatedCustomException(e.status(),e.contentUTF8());
        }
    }



}
